@@ -3,7 +3,7 @@ package Net::Async::MPD;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use IO::Async::Loop;
 use IO::Async::Stream;
@@ -530,7 +530,7 @@ MPD supports sending command lists to make it easier to perform a series of
 steps as a single one. No command is executed until all commands in the list
 have been sent, and then the server returns the result for all of them together.
 See the
-L<MPD documentation||https://musicpd.org/doc/protocol/command_lists.html>
+L<MPD documentation|https://musicpd.org/doc/protocol/command_lists.html>
 for more information.
 
 L<Net::Async::MPD> fully supports sending command lists, and makes it easy to
@@ -678,7 +678,7 @@ argument. Valid keys to use are:
 =item B<list>
 
 If set to false, results of command lists will be parsed as a single result.
-When set to true, each command in a command list is aprsed independently. See
+When set to true, each command in a command list is parsed independently. See
 L</"Server Responses"> for more details.
 
 Defaults to true. This value is ignored when not sending a command list.
@@ -703,7 +703,13 @@ regardless of how many commands were sent.
 =back
 
 For ease of use, underscores in the final command name will be removed before
-sending to the server (unless the command name requires them).
+sending to the server (unless the command name requires them). So
+
+    $client->send( 'current_song' );
+
+is entirely equivalent to
+
+    $client->send( 'currentsong' );
 
 =item B<get>
 
@@ -754,11 +760,11 @@ information on how to register subscribers to the different events.
 =item B<until>
 
 In addition to methods like C<on> and C<once>, provided by
-L<Role::EventEmitter>,this module also exposes an C<until> method, which
+L<Role::EventEmitter>, this module also exposes an C<until> method, which
 registers a listener until a certain condition is true, and then deregisters it.
 
-The method is called with two subroutine references. The first is unsubscribed
-as a regular listener, and the second is called only then the first one returns
+The method is called with two subroutine references. The first is subscribed
+as a regular listener, and the second is called only when the first one returns
 a true value. At that point, the entire set is unsubscribed.
 
 =back
@@ -766,8 +772,8 @@ a true value. At that point, the entire set is unsubscribed.
 =head2 Event descriptions
 
 After calling B<idle>, the client will be in idle mode, which means that any
-changes to the specified subsystemswill trigger a signal. When the client
-receives this signal, it will fire an event named as the subsystem that fired
+changes to the specified subsystems will trigger a signal. When the client
+receives this signal, it will fire an event named like the subsystem that fired
 it.
 
 The event will be fired with the client as the first argument, and the response
@@ -819,7 +825,7 @@ A partition was added, removed or changed.
 
 =item B<sticker>
 
-The sticket database has been modified.
+The sticker database has been modified.
 
 =item B<subscription>
 
@@ -852,6 +858,12 @@ users are I<not> required to register to this event for safe execution.
 
 =over 4
 
+=item * L<AnyEvent::Net::MPD>
+
+A previous attempt at writing this distribution, based on L<AnyEvent>. Although
+the design is largely the same, it is not as fully featured or as well tested
+as this one.
+
 =item * L<Net::MPD>
 
 A lightweight blocking MPD library. Has fewer dependencies than this one, but
@@ -891,7 +903,7 @@ José Joaquín Atria <jjatria@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by José Joaquín Atria.
+This software is copyright (c) 2017-2018 by José Joaquín Atria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
